@@ -13,14 +13,9 @@ import re
 from subprocess import Popen
 import sys
 
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
 from jsonschema import Draft4Validator as Validator
 from jsonschema import RefResolver
-from pytest import fixture, skip, mark
+from pytest import fixture, skip
 import nbformat
 
 from .utils import call, have_git, have_hg, wait_up, TEST_TOKEN
@@ -38,7 +33,7 @@ except ImportError:
         pass
     def popen_wait(p, timeout):
         """backport of Popen.wait from Python 3"""
-        for i in range(int(10 * timeout)):
+        for _ in range(int(10 * timeout)):
             if p.poll() is not None:
                 return
             time.sleep(0.1)
@@ -73,22 +68,6 @@ def tempfiles(tmpdir, filespath):
     return str(dest)
 
 
-@fixture
-def nocolor(request):
-    """Disable color printing for test"""
-    import nbdime.prettyprint as pp
-    patch = mock.patch.multiple(
-        pp,
-        ADD=pp.ADD.replace(pp.GREEN, ''),
-        REMOVE=pp.REMOVE.replace(pp.RED, ''),
-        INFO=pp.INFO.replace(pp.BLUE, ''),
-        RESET='',
-        git_diff_print_cmd=pp.git_diff_print_cmd.replace(' --color-words', ''),
-    )
-    patch.start()
-    request.addfinalizer(patch.stop)
-
-
 @fixture(scope='session')
 def needs_git():
     if not have_git:
