@@ -5,13 +5,10 @@
 
 from __future__ import unicode_literals
 
-import pytest
 from nbdime import merge_notebooks
 
 from nbdime.nbmergeapp import _build_arg_parser
 
-from .utils import have_git
-
 # FIXME: Extend tests to more merge situations!
 
 
@@ -112,8 +109,7 @@ def test_autoresolve_notebook_ignore_fallback():
     assert not any(d.conflict for d in decisions)
 
 
-@pytest.mark.skipif(not have_git, reason="Missing git.")
-def test_autoresolve_inline_source_conflict(db):
+def test_autoresolve_inline_source_conflict(db, needs_git):
     nbb = db["inline-conflict--1"]
     nbl = db["inline-conflict--2"]
     nbr = db["inline-conflict--3"]
@@ -127,33 +123,7 @@ def test_autoresolve_inline_source_conflict(db):
 
     source = merged.cells[0].source
 
-    git_expected = """\
-x = 1
-<<<<<<< local
-y = 3
-print(x * y)
-=======
-q = 3.1
-print(x + q)
->>>>>>> remote"""
-
-    builtin_expected_course = """\
-<<<<<<< local
-x = 1
-y = 3
-z = 4
-print(x * y / z)
-=======
-x = 1
-q = 3.1
-print(x + q)
->>>>>>> remote"""
-    # ||||||| base
-    # x = 1
-    # y = 3
-    # print(x * y)
-
-    builtin_expected_finegrained = """\
+    expected = """\
 x = 1
 <<<<<<< local
 y = 3
@@ -164,7 +134,4 @@ q = 3.1
 print(x + q)
 >>>>>>> remote"""
 
-    expected = builtin_expected_finegrained
-
     assert source == expected
-
