@@ -26,6 +26,7 @@ from subprocess import check_call, CalledProcessError
 from nbdime.args import (
     add_git_config_subcommand, add_generic_args, add_diff_args, add_web_args,
     add_git_diff_driver_args, add_diff_cli_args, ConfigBackedParser,
+    add_prettyprint_args
     )
 from nbdime.utils import locate_gitattributes, ensure_dir_exists, setup_std_streams
 from .filter_integration import apply_possible_filter
@@ -38,7 +39,7 @@ def enable(scope=None):
 
     try:
         check_call(cmd + ['diff.jupyternotebook.command', 'git-nbdiffdriver diff'])
-    except CalledProcessError as e:
+    except CalledProcessError:
         return   # Not in git repository
     gitattributes = locate_gitattributes(scope)
     if gitattributes is None:
@@ -86,6 +87,7 @@ def _build_arg_parser():
     add_git_diff_driver_args(diff_parser)
     add_diff_args(diff_parser)
     add_diff_cli_args(diff_parser)
+    add_prettyprint_args(diff_parser)
 
     webdiff_parser = subparsers.add_parser('webdiff',
         description="The actual entrypoint for the webdiff tool. Git will call this."
@@ -95,7 +97,7 @@ def _build_arg_parser():
     add_web_args(webdiff_parser, 0)
 
     # TODO: From git docs: "For a path that is unmerged, GIT_EXTERNAL_DIFF is called with 1 parameter, <path>."
-    config = add_git_config_subcommand(subparsers,
+    add_git_config_subcommand(subparsers,
         enable, disable,
         subparser_help="Configure git to use nbdime for notebooks in `git diff`",
         enable_help="enable nbdime diff driver via git config",
