@@ -12,9 +12,17 @@ from notebook.utils import url_path_join, to_os_path
 from notebook.services.contents.checkpoints import GenericCheckpointsMixin
 from notebook.services.contents.filecheckpoints import FileCheckpoints
 from tornado.web import HTTPError, escape, authenticated, gen
-import nbformat
 
-import nbdime
+from ..args import process_diff_flags
+from ..config import build_config, Namespace
+from ..diffing.notebooks import set_notebook_diff_ignores, diff_notebooks
+from ..gitfiles import (
+    changed_notebooks, is_path_in_repo, find_repo_root,
+    InvalidGitRepositoryError, BadName, GitCommandNotFound,
+    )
+from ..ignorables import diff_ignorables
+from ..utils import read_notebook
+
 from .nbdimeserver import (
     template_path,
     static_path,
@@ -24,16 +32,6 @@ from .nbdimeserver import (
     APIHandler,
 )
 
-from ..gitfiles import (
-    changed_notebooks, is_path_in_repo, find_repo_root,
-    InvalidGitRepositoryError, BadName, GitCommandNotFound,
-    apply_possible_filter
-    )
-from ..utils import split_os_path, EXPLICIT_MISSING_FILE, read_notebook
-from ..config import build_config, Namespace
-from ..diffing.notebooks import set_notebook_diff_ignores
-from ..args import process_diff_flags, diff_exclusives
-
 
 class AuthMainDifftoolHandler(MainDifftoolHandler):
     @authenticated
@@ -53,8 +51,6 @@ class GitDifftoolHandler(NbdimeHandler):
         self.write(self.render_template(
             'difftool.html',
             config_data=args,
-            mathjax_url=self.mathjax_url,
-            mathjax_config=self.mathjax_config,
             ))
 
 
@@ -70,8 +66,6 @@ class CheckpointDifftoolHandler(NbdimeHandler):
         self.write(self.render_template(
             'difftool.html',
             config_data=args,
-            mathjax_url=self.mathjax_url,
-            mathjax_config=self.mathjax_config,
             ))
 
 
@@ -158,7 +152,7 @@ class ExtensionApiDiffHandler(ApiDiffHandler):
 
         # Perform actual diff and return data:
         try:
-            thediff = nbdime.diff_notebooks(base_nb, remote_nb)
+            thediff = diff_notebooks(base_nb, remote_nb)
         except Exception:
             self.log.exception('Error diffing documents:')
             raise HTTPError(500, 'Error while attempting to diff documents')
@@ -213,7 +207,7 @@ def _load_jupyter_server_extension(nb_server_app):
 
     config = build_config('extension')
     ignore = config.pop('Ignore', None)
-    for k in diff_exclusives:
+    for k in diff_ignorables:
         config[k] = config.get(k, None)
     ns = Namespace(config)
     process_diff_flags(ns)
